@@ -2,41 +2,57 @@
 #'
 #' @description
 #' These functions create an R project:
-#'   * `create_package()` creates an R package
+#'   * `create_package()` creates an R package.
 #'   * `create_project()` creates a non-package project, i.e. a data analysis
-#'   project
+#'     project.
+#'   * `r lifecycle::badge("experimental")` `create_quarto_project()` creates a
+#'     Quarto project. It is a simplified convenience wrapper around
+#'     [quarto::quarto_create_project()], which you should call directly for
+#'     more advanced usage.
 #'
-#' Both functions can be called on an existing project; you will be asked before
-#' any existing files are changed.
+#' These functions work best when creating a project *de novo*, but
+#' `create_package()` and `create_project()` can be called on an existing
+#' project; you will be asked before any existing files are changed.
 #'
 #' @inheritParams use_description
+#' @param fields A named list of fields to add to `DESCRIPTION`, potentially
+#'   overriding default values. See [use_description()] for how you can set
+#'   personalized defaults using package options.
 #' @param path A path. If it exists, it is used. If it does not exist, it is
 #'   created, provided that the parent path exists.
 #' @param roxygen Do you plan to use roxygen2 to document your package?
 #' @param rstudio If `TRUE`, calls [use_rstudio()] to make the new package or
 #'   project into an [RStudio
 #'   Project](https://r-pkgs.org/workflow101.html#sec-workflow101-rstudio-projects).
-#'    If `FALSE` and a non-package project, a sentinel `.here` file is placed so
-#'   that the directory can be recognized as a project by the
-#'   [here](https://here.r-lib.org) or
-#'   [rprojroot](https://rprojroot.r-lib.org) packages.
+#'
+#'   If `FALSE`, the goal is to ensure that the directory can be recognized as
+#'   a project by, for example, the [here](https://here.r-lib.org) package. If
+#'   the project is neither an R package nor a Quarto project, a sentinel
+#'   `.here` file is placed to mark the project root.
 #' @param open If `TRUE`, [activates][proj_activate()] the new project:
 #'
-#'   * If using RStudio desktop, the package is opened in a new session.
-#'   * If on RStudio server, the current RStudio project is activated.
-#'   * Otherwise, the working directory and active project is changed.
+#'   * If using RStudio or Positron, the new project is opened in a new session,
+#'     window, or browser tab, depending on the product (RStudio or Positron)
+#'     and context (desktop or server).
+#'   * Otherwise, the working directory and active project of the current R
+#'     session are changed to the new project.
+#' @param type The type of Quarto project to create. See
+#'   `?quarto::quarto_create_project` for the most up-to-date list, but
+#'   `"website"`, `"blog"`, `"book"`, and `"manuscript"` are common choices.
 #'
-#' @return Path to the newly created project or package, invisibly.
+#' @returns Path to the newly created project or package, invisibly.
 #' @seealso [create_tidy_package()] is a convenience function that extends
 #'   `create_package()` by immediately applying as many of the tidyverse
 #'   development conventions as possible.
 #' @export
-create_package <- function(path,
-                           fields = list(),
-                           rstudio = rstudioapi::isAvailable(),
-                           roxygen = TRUE,
-                           check_name = TRUE,
-                           open = rlang::is_interactive()) {
+create_package <- function(
+  path,
+  fields = list(),
+  rstudio = rstudioapi::isAvailable(),
+  roxygen = TRUE,
+  check_name = TRUE,
+  open = rlang::is_interactive()
+) {
   path <- user_path_prep(path)
   check_path_is_directory(path_dir(path))
 
@@ -71,10 +87,14 @@ create_package <- function(path,
 
 #' @export
 #' @rdname create_package
-create_project <- function(path,
-                           rstudio = rstudioapi::isAvailable(),
-                           open = rlang::is_interactive()) {
+create_project <- function(
+  path,
+  rstudio = rstudioapi::isAvailable(),
+  open = rlang::is_interactive()
+) {
   path <- user_path_prep(path)
+  check_path_is_directory(path_dir(path))
+
   name <- path_file(path_abs(path))
   challenge_nested_project(path_dir(path), name)
   challenge_home_directory(path)
@@ -87,9 +107,11 @@ create_project <- function(path,
   if (rstudio) {
     use_rstudio()
   } else {
-    ui_done("Writing a sentinel file {ui_path('.here')}")
-    ui_todo("Build robust paths within your project via {ui_code('here::here()')}")
-    ui_todo("Learn more at <https://here.r-lib.org>")
+    ui_bullets(c(
+      "v" = "Writing a sentinel file {.path .here}.",
+      "_" = "Build robust paths within your project via {.fun here::here}.",
+      "i" = "Learn more at {.url https://here.r-lib.org}."
+    ))
     file_create(proj_path(".here"))
   }
 
@@ -104,6 +126,50 @@ create_project <- function(path,
   invisible(proj_get())
 }
 
+#' @rdname create_package
+#' @export
+create_quarto_project <- function(
+  path,
+  type = "default",
+  rstudio = rstudioapi::isAvailable(),
+  open = rlang::is_interactive()
+) {
+  check_installed("quarto")
+
+  path <- user_path_prep(path)
+  parent_dir <- path_dir(path)
+  check_path_is_directory(parent_dir)
+
+  name <- path_file(path_abs(path))
+  challenge_nested_project(parent_dir, name)
+  challenge_home_directory(path)
+
+  create_directory(path)
+  local_project(path, force = TRUE)
+
+  if (rstudio) {
+    use_rstudio()
+  }
+
+  res <- quarto::quarto_create_project(
+    name = name,
+    dir = parent_dir,
+    type = type,
+    no_prompt = TRUE,
+    quiet = getOption("usethis.quiet", default = FALSE)
+  )
+
+  if (open) {
+    if (proj_activate(proj_get())) {
+      # working directory/active project already set; clear the scheduled
+      # restoration of the original project
+      withr::deferred_clear()
+    }
+  }
+
+  invisible(proj_get())
+}
+
 #' Create a project from a GitHub repo
 #'
 #' @description
@@ -177,21 +243,15 @@ create_project <- function(path,
 #' # a URL repo_spec also specifies the host (e.g. GitHub Enterprise instance)
 #' create_from_github("https://github.acme.com/OWNER/REPO")
 #' }
-create_from_github <- function(repo_spec,
-                               destdir = NULL,
-                               fork = NA,
-                               rstudio = NULL,
-                               open = rlang::is_interactive(),
-                               protocol = git_protocol(),
-                               host = NULL,
-                               auth_token = deprecated(),
-                               credentials = deprecated()) {
-  if (lifecycle::is_present(auth_token)) {
-    deprecate_warn_auth_token("create_from_github")
-  }
-  if (lifecycle::is_present(credentials)) {
-    deprecate_warn_credentials("create_from_github")
-  }
+create_from_github <- function(
+  repo_spec,
+  destdir = NULL,
+  fork = NA,
+  rstudio = NULL,
+  open = rlang::is_interactive(),
+  protocol = git_protocol(),
+  host = NULL
+) {
   check_protocol(protocol)
 
   parsed_repo_spec <- parse_repo_url(repo_spec)
@@ -206,26 +266,26 @@ create_from_github <- function(repo_spec,
   hint <- code_hint_with_host("gh_token_help", host)
 
   if (no_auth && is.na(fork)) {
-    ui_stop("
-      Unable to discover a GitHub personal access token
-      Therefore, can't determine your permissions on {ui_value(repo_spec)}
-      Therefore, can't decide if `fork` should be `TRUE` or `FALSE`
-
-      You have two choices:
-      1. Make your token available (if in doubt, DO THIS):
-         - Call {ui_code(hint)} for directions
-      2. Call {ui_code('create_from_github()')} again, but with \\
-      {ui_code('fork = FALSE')}
-         - Only do this if you are absolutely sure you don't want to fork
-         - Note you will NOT be in a position to make a pull request")
+    ui_abort(c(
+      "x" = "Unable to discover a GitHub personal access token.",
+      "x" = "Therefore, can't determine your permissions on {.val {repo_spec}}.",
+      "x" = "Therefore, can't decide if {.arg fork} should be {.code TRUE} or {.code FALSE}.",
+      "",
+      "i" = "You have two choices:",
+      "_" = "Make your token available (if in doubt, DO THIS):",
+      " " = "Call {.code {hint}} for instructions that should help.",
+      "_" = "Call {.fun create_from_github} again, but with {.code fork = FALSE}.",
+      " " = "Only do this if you are absolutely sure you don't want to fork.",
+      " " = "Note you will NOT be in a position to make a pull request."
+    ))
   }
 
   if (no_auth && isTRUE(fork)) {
-    ui_stop("
-      Unable to discover a GitHub personal access token
-      A token is required in order to fork {ui_value(repo_spec)}
-
-      Call {ui_code(hint)} for help configuring a token")
+    ui_abort(c(
+      "x" = "Unable to discover a GitHub personal access token.",
+      "i" = "A token is required in order to fork {.val {repo_spec}}.",
+      "_" = "Call {.code {hint}} for help configuring a token."
+    ))
   }
   # one of these is true:
   # - gh is discovering a token for `host`
@@ -233,7 +293,11 @@ create_from_github <- function(repo_spec,
 
   source_owner <- spec_owner(repo_spec)
   repo_name <- spec_repo(repo_spec)
-  gh <- gh_tr(list(repo_owner = source_owner, repo_name = repo_name, api_url = host))
+  gh <- gh_tr(list(
+    repo_owner = source_owner,
+    repo_name = repo_name,
+    api_url = host
+  ))
 
   repo_info <- gh("GET /repos/{owner}/{repo}")
   # 2023-01-28 We're seeing the GitHub bug again around default branch in a
@@ -246,14 +310,16 @@ create_from_github <- function(repo_spec,
   if (is.na(fork)) {
     fork <- !isTRUE(repo_info$permissions$push)
     fork_status <- glue("fork = {fork}")
-    ui_done("Setting {ui_code(fork_status)}")
+    ui_bullets(c("v" = "Setting {.code {fork_status}}."))
   }
   # fork is either TRUE or FALSE
 
   if (fork && identical(user, repo_info$owner$login)) {
-    ui_stop("
-      Can't fork, because the authenticated user {ui_value(user)} \\
-      already owns the source repo {ui_value(repo_info$full_name)}")
+    ui_abort(
+      "
+      Can't fork, because the authenticated user {.val {user}} already owns the
+      source repo {.val {repo_info$full_name}}."
+    )
   }
 
   destdir <- user_path_prep(destdir %||% conspicuous_place())
@@ -265,14 +331,14 @@ create_from_github <- function(repo_spec,
 
   if (fork) {
     ## https://developer.github.com/v3/repos/forks/#create-a-fork
-    ui_done("Forking {ui_value(repo_info$full_name)}")
+    ui_bullets(c("v" = "Forking {.val {repo_info$full_name}}."))
     upstream_url <- switch(
       protocol,
       https = repo_info$clone_url,
       ssh = repo_info$ssh_url
     )
     repo_info <- gh("POST /repos/{owner}/{repo}/forks")
-    ui_done("Waiting for the fork to finalize before cloning")
+    ui_bullets(c("i" = "Waiting for the fork to finalize before cloning..."))
     Sys.sleep(3)
   }
 
@@ -282,7 +348,9 @@ create_from_github <- function(repo_spec,
     ssh = repo_info$ssh_url
   )
 
-  ui_done("Cloning repo from {ui_value(origin_url)} into {ui_value(repo_path)}")
+  ui_bullets(c(
+    "v" = "Cloning repo from {.val {origin_url}} into {.path {repo_path}}."
+  ))
   gert::git_clone(origin_url, repo_path, verbose = FALSE)
 
   proj_path <- find_rstudio_root(repo_path)
@@ -291,19 +359,26 @@ create_from_github <- function(repo_spec,
   # 2023-01-28 again, it would be more natural to trust the default branch of
   # the fork, but that cannot always be trusted. For now, we're still using
   # the default branch learned from the source repo.
-  ui_info("Default branch is {ui_value(default_branch)}")
+  ui_bullets(c("i" = "Default branch is {.val {default_branch}}."))
 
   if (fork) {
-    ui_done("Adding {ui_value('upstream')} remote: {ui_value(upstream_url)}")
+    ui_bullets(c(
+      "v" = "Adding {.val upstream} remote: {.val {upstream_url}}"
+    ))
     use_git_remote("upstream", upstream_url)
     pr_merge_main()
     upstream_remref <- glue("upstream/{default_branch}")
-    ui_done("
-      Setting remote tracking branch for local {ui_value(default_branch)} \\
-      branch to {ui_value(upstream_remref)}")
+    ui_bullets(c(
+      "v" = "Setting remote tracking branch for local {.val {default_branch}}
+             branch to {.val {upstream_remref}}."
+    ))
     gert::git_branch_set_upstream(upstream_remref, repo = git_repo())
     config_key <- glue("remote.upstream.created-by")
-    gert::git_config_set(config_key, "usethis::create_from_github", repo = git_repo())
+    gert::git_config_set(
+      config_key,
+      "usethis::create_from_github",
+      repo = git_repo()
+    )
   }
 
   rstudio <- rstudio %||% rstudio_available()
@@ -334,7 +409,8 @@ find_rstudio_root <- function(path) {
 }
 
 challenge_nested_project <- function(path, name) {
-  if (!possibly_in_proj(path)) {
+  enclosing_project <- proj_find(path)
+  if (is.null(enclosing_project)) {
     return(invisible())
   }
 
@@ -344,15 +420,18 @@ challenge_nested_project <- function(path, name) {
     return(invisible())
   }
 
-  ui_line(
-    "New project {ui_value(name)} is nested inside an existing project \\
-    {ui_path(path)}, which is rarely a good idea.
-    If this is unexpected, the here package has a function, \\
-    {ui_code('here::dr_here()')} that reveals why {ui_path(path)} \\
-    is regarded as a project."
-  )
-  if (ui_nope("Do you want to create anyway?")) {
-    ui_stop("Cancelling project creation.")
+  ui_bullets(c(
+    "!" = "New project {.path {path(path, name)}} would be nested inside an
+           existing project {.path {pth(enclosing_project)}}, which is rarely a
+           good idea.",
+    "i" = "If this is unexpected, the {.pkg here} package has a function,
+           {.fun here::dr_here} that reveals why a particular path is regarded
+           as a project. To learn more, run {.fun here::dr_here} in a fresh R
+           session that has {.path {pth(enclosing_project)}} as working
+           directory."
+  ))
+  if (ui_nah("Do you want to create anyway?")) {
+    ui_abort("Cancelling project creation.")
   }
   invisible()
 }
@@ -368,12 +447,13 @@ challenge_home_directory <- function(path) {
   } else {
     ""
   }
-  ui_line("
-    {ui_path(path)} is {qualification}your home directory.
-    It is generally a bad idea to create a new project here.
-    You should probably create your new project in a subdirectory.")
-  if (ui_nope("Do you want to create anyway?")) {
-    ui_stop("Good move! Cancelling project creation.")
+  ui_bullets(c(
+    "!" = "{.path {pth(path)}} is {qualification}your home directory.",
+    "i" = "It is generally a bad idea to create a new project here.",
+    "i" = "You should probably create your new project in a subdirectory."
+  ))
+  if (ui_nah("Do you want to create anyway?")) {
+    ui_abort("Good move! Cancelling project creation.")
   }
   invisible()
 }
