@@ -175,7 +175,8 @@ use_apl2_license <- function() {
 use_license_template <- function(license, data = list()) {
   license_template <- glue("license-{license}.md")
 
-  use_template(license_template,
+  use_template(
+    license_template,
     save_as = "LICENSE.md",
     data = data,
     ignore = TRUE
@@ -186,8 +187,7 @@ check_license_version <- function(version, possible) {
   version <- as.double(version)
 
   if (!version %in% possible) {
-    possible <- glue_collapse(possible, sep = ", ", last = ", or ")
-    ui_stop("`version` must be {possible}")
+    ui_abort("{.arg version} must be {.or {possible}}.")
   }
 
   version
