@@ -14,18 +14,25 @@ proj_set_ <- function(path) {
 #' Most `use_*()` functions act on the **active project**. If it is
 #' unset, usethis uses [rprojroot](https://rprojroot.r-lib.org) to
 #' find the project root of the current working directory. It establishes the
-#' project root by looking for a `.here` file, an RStudio Project, a package
-#' `DESCRIPTION`, Git infrastructure, a `remake.yml` file, or a `.projectile`
-#' file. It then stores the active project for use for the remainder of the
+#' project root by looking for signs such as:
+#' * a `.here` file
+#' * an RStudio Project, i.e. a `.Rproj` file
+#' * an R package, i.e. a `DESCRIPTION` file
+#' * a Git repository
+#' * a Positron or VS Code workspace, i.e. a `.vscode/settings.json` file
+#' * a Quarto project, i.e. a `_quarto.yml` file
+#' * an renv project, i.e. a `renv.lock` file
+#'
+#' usethis then stores the active project for use for the remainder of the
 #' session.
 #'
 #' In general, end user scripts should not contain direct calls to
 #' `usethis::proj_*()` utility functions. They are internal functions that are
 #' exported for occasional interactive use or use in packages that extend
-#' usethis. End user code should call functions in
-#' [rprojroot](https://rprojroot.r-lib.org) or its simpler companion,
-#' [here](https://here.r-lib.org), to programmatically detect a project and
-#' build paths within it.
+#' usethis. End user code should call `here::here()` or other functions from
+#' the [here](https://here.r-lib.org) or
+#' [rprojroot](https://rprojroot.r-lib.org) packages to programmatically
+#' detect a project and build paths within it.
 #'
 #' If you are puzzled why a path (usually the current working directory) does
 #' *not* appear to be inside project, it can be helpful to call
@@ -81,16 +88,17 @@ proj_set <- function(path = ".", force = FALSE) {
   path <- proj_path_prep(path)
   if (is.null(path) || force) {
     proj_string <- if (is.null(path)) "<no active project>" else path
-    ui_done("Setting active project to {ui_value(proj_string)}")
+    ui_bullets(c("v" = "Setting active project to {.val {proj_string}}."))
     return(proj_set_(path))
   }
 
   check_path_is_directory(path)
   new_project <- proj_find(path)
   if (is.null(new_project)) {
-    ui_stop('
-      Path {ui_path(path)} does not appear to be inside a project or package.
-      Read more in the help for {ui_code("proj_get()")}.')
+    ui_abort(c(
+      "Path {.path {pth(path)}} does not appear to be inside a project or package.",
+      "Read more in the help for {.fun usethis::proj_get}."
+    ))
   }
   proj_set(path = new_project, force = TRUE)
 }
@@ -103,7 +111,7 @@ proj_path <- function(..., ext = "") {
   has_absolute_path <- function(x) any(is_absolute_path(x))
   dots <- list(...)
   if (any(map_lgl(dots, has_absolute_path))) {
-    ui_stop("Paths must be relative to the active project")
+    ui_abort("Paths must be relative to the active project, not absolute.")
   }
 
   path_norm(path(proj_get(), ..., ext = ext))
@@ -118,11 +126,13 @@ proj_path <- function(..., ext = "") {
 #' @param quiet Whether to suppress user-facing messages, while operating in the
 #'   temporary active project
 #' @export
-with_project <- function(path = ".",
-                         code,
-                         force = FALSE,
-                         setwd = TRUE,
-                         quiet = getOption("usethis.quiet", default = FALSE)) {
+with_project <- function(
+  path = ".",
+  code,
+  force = FALSE,
+  setwd = TRUE,
+  quiet = getOption("usethis.quiet", default = FALSE)
+) {
   local_project(path = path, force = force, setwd = setwd, quiet = quiet)
   force(code)
 }
@@ -134,17 +144,19 @@ with_project <- function(path = ".",
 #' @param .local_envir The environment to use for scoping. Defaults to current
 #'   execution environment.
 #' @export
-local_project <- function(path = ".",
-                          force = FALSE,
-                          setwd = TRUE,
-                          quiet = getOption("usethis.quiet", default = FALSE),
-                          .local_envir = parent.frame()) {
+local_project <- function(
+  path = ".",
+  force = FALSE,
+  setwd = TRUE,
+  quiet = getOption("usethis.quiet", default = FALSE),
+  .local_envir = parent.frame()
+) {
   withr::local_options(usethis.quiet = quiet, .local_envir = .local_envir)
 
   old_project <- proj_get_() # this could be `NULL`, i.e. no active project
   withr::defer(proj_set(path = old_project, force = TRUE), envir = .local_envir)
   proj_set(path = path, force = force)
-  temp_proj <- proj_get_()   # this could be `NULL`
+  temp_proj <- proj_get_() # this could be `NULL`
 
   if (isTRUE(setwd) && !is.null(temp_proj)) {
     withr::local_dir(temp_proj, .local_envir = .local_envir)
@@ -185,6 +197,10 @@ proj_crit <- function() {
     rprojroot::is_rstudio_project |
     rprojroot::is_r_package |
     rprojroot::is_git_root |
+    # use rprojroot::is_vscode_project at some point in the future
+    rprojroot::has_file(".vscode/settings.json") |
+    rprojroot::is_quarto_project |
+    rprojroot::is_renv_project |
     rprojroot::is_remake_project |
     rprojroot::is_projectile_project
 }
@@ -211,21 +227,23 @@ check_is_package <- function(whos_asking = NULL) {
     return(invisible())
   }
 
-  message <- "Project {ui_value(project_name())} is not an R package."
+  message <- "Project {.val {project_name()}} is not an R package."
   if (!is.null(whos_asking)) {
+    whos_asking_fn <- sub("()", "", whos_asking, fixed = TRUE)
     message <- c(
-      "{ui_code(whos_asking)} is designed to work with packages.",
-      message
+      "i" = "{.topic [{whos_asking}](usethis::{whos_asking_fn})} is designed to work with packages.",
+      "x" = message
     )
   }
-  ui_stop(message)
+  ui_abort(message)
 }
 
 check_is_project <- function() {
   if (!possibly_in_proj()) {
-    ui_stop('
-      We do not appear to be inside a valid project or package.
-      Read more in the help for {ui_code("proj_get()")}.')
+    ui_abort(c(
+      "We do not appear to be inside a valid project or package.",
+      "Read more in the help for {.fun usethis::proj_get}."
+    ))
   }
 }
 
@@ -260,10 +278,17 @@ project_name <- function(base_path = proj_get()) {
 
 #' Activate a project
 #'
-#' Activates a project in usethis, R session, and (if relevant) RStudio senses.
-#' If you are in RStudio, this will open a new RStudio session. If not, it will
+#' Activates a project in the usethis, R session, and (if relevant) RStudio
+#' senses. If you are in RStudio, this will open a new RStudio session. If not, it will
 #' change the working directory and [active project][proj_set()].
 #'
+#' * If using RStudio desktop, the project is opened in a new session.
+#'   * If using Positron, the project is opened in a new window.
+#'   * If using RStudio or Positron on a server, the project is opened in a new
+#'     browser tab.
+#'   * Otherwise, the working directory and active project is changed in the
+#'     current R session.
+#'
 #' @param path Project directory
 #' @return Single logical value indicating if current session is modified.
 #' @export
@@ -272,14 +297,20 @@ proj_activate <- function(path) {
   path <- user_path_prep(path)
 
   if (rstudio_available() && rstudioapi::hasFun("openProject")) {
-    ui_done("Opening {ui_path(path, base = NA)} in new RStudio session")
+    # TODO: Perhaps in future this message can be specialized for RStudio vs.
+    # Positron. For now, I've just made it more generic to work better for both.
+    ui_bullets(c(
+      "v" = "Opening {.path {pth(path, base = NA)}} in a new session."
+    ))
     rstudioapi::openProject(path, newSession = TRUE)
     invisible(FALSE)
   } else {
     proj_set(path)
     rel_path <- path_rel(proj_get(), path_wd())
     if (rel_path != ".") {
-      ui_done("Changing working directory to {ui_path(path, base = NA)}")
+      ui_bullets(c(
+        "v" = "Changing working directory to {.path {pth(path, base = NA)}}"
+      ))
       setwd(proj_get())
     }
     invisible(TRUE)
