@@ -36,11 +36,12 @@ use_release_issue <- function(version = NULL) {
   check_is_package("use_release_issue()")
   tr <- target_repo(github_get = TRUE)
   if (!isTRUE(tr$can_push)) {
-    ui_line("
-      It is very unusual to open a release issue on a repo you can't push to:
-        {ui_value(tr$repo_spec)}")
-    if (ui_nope("Do you really want to do this?")) {
-      ui_oops("Cancelling.")
+    ui_bullets(c(
+      "!" = "It is very unusual to open a release issue on a repo you can't push
+             to ({.val {tr$repo_spec}})."
+    ))
+    if (ui_nah("Do you really want to do this?")) {
+      ui_bullets(c("x" = "Cancelling."))
       return(invisible())
     }
   }
@@ -55,7 +56,7 @@ use_release_issue <- function(version = NULL) {
   }
 
   on_cran <- !is.null(cran_version())
-  checklist <- release_checklist(version, on_cran)
+  checklist <- release_checklist(version, on_cran, tr)
 
   gh <- gh_tr(tr)
   issue <- gh(
@@ -68,51 +69,56 @@ use_release_issue <- function(version = NULL) {
   view_url(issue$html_url)
 }
 
-release_checklist <- function(version, on_cran) {
+release_checklist <- function(version, on_cran, target_repo = NULL) {
   type <- release_type(version)
   cran_results <- cran_results_url()
   has_news <- file_exists(proj_path("NEWS.md"))
   has_pkgdown <- uses_pkgdown()
   has_lifecycle <- proj_desc()$has_dep("lifecycle")
   has_readme <- file_exists(proj_path("README.Rmd"))
-  has_github_links <- has_github_links()
+  has_github_links <- has_github_links(target_repo)
   is_posit_pkg <- is_posit_pkg()
-
-  milestone_num <- NA # for testing (and general fallback)
-  if (uses_git() && curl::has_internet()) {
-    milestone_num <- tryCatch(
-      gh_milestone_number(target_repo_spec(), version),
-      error = function(e) NA
-    )
-  }
+  milestone_num <- gh_milestone_number(target_repo, version)
 
   c(
-    if (!on_cran) c(
-      "First release:",
-      "",
-      todo("`usethis::use_news_md()`", !has_news),
-      todo("`usethis::use_cran_comments()`"),
-      todo("Update (aspirational) install instructions in README"),
-      todo("Proofread `Title:` and `Description:`"),
-      todo("Check that all exported functions have `@return` and `@examples`"),
-      todo("Check that `Authors@R:` includes a copyright holder (role 'cph')"),
-      todo("Check [licensing of included files](https://r-pkgs.org/license.html#sec-code-you-bundle)"),
-      todo("Review <https://github.com/DavisVaughan/extrachecks>"),
-      ""
-    ),
+    if (!on_cran) {
+      c(
+        "First release:",
+        "",
+        todo("`usethis::use_news_md()`", !has_news),
+        todo("`usethis::use_cran_comments()`"),
+        todo("Update (aspirational) install instructions in README"),
+        todo("Proofread `Title:` and `Description:`"),
+        todo(
+          "Check that all exported functions have `@return` and `@examples`"
+        ),
+        todo(
+          "Check that `Authors@R:` includes a copyright holder (role 'cph')"
+        ),
+        todo(
+          "Check [licensing of included files](https://r-pkgs.org/license.html#sec-code-you-bundle)"
+        ),
+        todo("Review <https://github.com/DavisVaughan/extrachecks>"),
+        ""
+      )
+    },
     "Prepare for release:",
     "",
     todo("`git pull`"),
-    if (!is.na(milestone_num)) {
-      todo("[Close v{version} milestone](../milestone/{milestone_num})")
-    },
+    todo(
+      "[Close v{version} milestone](../milestone/{milestone_num})",
+      !is.na(milestone_num)
+    ),
     todo("Check [current CRAN check results]({cran_results})", on_cran),
-    todo("
-      Check if any deprecation processes should be advanced, as described in \\
-      [Gradual deprecation](https://lifecycle.r-lib.org/articles/communicate.html#gradual-deprecation)",
-      type != "patch" && has_lifecycle),
+    todo(
+      "[Advance deprecations](https://lifecycle.r-lib.org/articles/communicate.html#gradual-deprecation), if needed",
+      type != "patch" && has_lifecycle
+    ),
     todo("`usethis::use_news_md()`", on_cran && !has_news),
-    todo("[Polish NEWS](https://style.tidyverse.org/news.html#news-release)", on_cran),
+    todo(
+      "[Polish NEWS](https://style.tidyverse.org/news.html#news-release)",
+      on_cran
+    ),
     todo("`usethis::use_github_links()`", !has_github_links),
     todo("`urlchecker::url_check()`"),
     todo("`devtools::build_readme()`", has_readme),
@@ -122,7 +128,6 @@ release_checklist <- function(version, on_cran) {
     todo("Update `cran-comments.md`", on_cran),
     todo("`git push`"),
     todo("Draft blog post", type != "patch"),
-    todo("Slack link to draft blog in #open-source-comms", type != "patch" && is_posit_pkg),
     release_extra_bullets(),
     "",
     "Submit to CRAN:",
@@ -139,15 +144,19 @@ release_checklist <- function(version, on_cran) {
     todo("`usethis::use_github_release()`"),
     todo("`usethis::use_dev_version(push = TRUE)`"),
     todo("`usethis::use_news_md()`", !has_news),
-    todo("Tweet", type != "patch")
+    todo("Share on social media", type != "patch"),
+    todo(
+      "Slack link to blog post, bluesky, and linkedin in #open-source-comms",
+      type != "patch" && is_posit_pkg
+    )
   )
 }
 
-gh_milestone_number <- function(repo_spec, version, state = "open") {
-  milestones <- gh::gh(
-    "/repos/{repo_spec}/milestones",
-    repo_spec = repo_spec,
-    state = state
+gh_milestone_number <- function(target_repo, version, state = "open") {
+  gh <- gh_tr(target_repo)
+  milestones <- tryCatch(
+    gh("/repos/{owner}/{repo}/milestones", state = state),
+    error = function(e) list()
   )
   titles <- map_chr(milestones, "title")
   numbers <- map_int(milestones, "number")
@@ -155,8 +164,18 @@ gh_milestone_number <- function(repo_spec, version, state = "open") {
   numbers[match(paste0("v", version), titles)]
 }
 
-release_revdepcheck <- function(on_cran = TRUE, is_posit_pkg = TRUE, env = NULL) {
-  if (!on_cran) {
+# Get revdeps for current package
+get_revdeps <- function() {
+  pkg <- proj_desc()$get_field("Package")
+  tools::package_dependencies(pkg, which = "all", reverse = TRUE)[[pkg]]
+}
+
+release_revdepcheck <- function(
+  on_cran = TRUE,
+  is_posit_pkg = TRUE,
+  env = NULL
+) {
+  if (!on_cran || length(get_revdeps()) == 0) {
     return()
   }
 
@@ -225,22 +244,11 @@ release_type <- function(version) {
 #' assume that current state (SHA of `HEAD`, package version, NEWS) is the
 #' submitted state.
 #'
-#' @param host,auth_token `r lifecycle::badge("deprecated")`: No longer
-#'   consulted now that usethis allows the gh package to lookup a token based on
-#'   a URL determined from the current project's GitHub remotes.
 #' @param publish If `TRUE`, publishes a release. If `FALSE`, creates a draft
 #'   release.
 #' @export
-use_github_release <- function(publish = TRUE,
-                               host = deprecated(),
-                               auth_token = deprecated()) {
+use_github_release <- function(publish = TRUE) {
   check_is_package("use_github_release()")
-  if (lifecycle::is_present(host)) {
-    deprecate_warn_host("use_github_release")
-  }
-  if (lifecycle::is_present(auth_token)) {
-    deprecate_warn_auth_token("use_github_release")
-  }
 
   tr <- target_repo(github_get = TRUE, ok_configs = c("ours", "fork"))
   check_can_push(tr = tr, "to create a release")
@@ -262,7 +270,7 @@ use_github_release <- function(publish = TRUE,
 
   gh <- gh_tr(tr)
 
-  ui_cli_inform("Publishing {tag_name} release to GitHub")
+  ui_bullets("Publishing {tag_name} release to GitHub")
   release <- gh(
     "POST /repos/{owner}/{repo}/releases",
     name = release_name,
@@ -271,10 +279,10 @@ use_github_release <- function(publish = TRUE,
     body = news,
     draft = !publish
   )
-  ui_cli_inform("Release at {.url {release$html_url}}")
+  ui_bullets("Release at {.url {release$html_url}}")
 
   if (!is.null(dat$file)) {
-    ui_cli_inform("Deleting {.path {dat$file}}")
+    ui_bullets("Deleting {.path {dat$file}}")
     file_delete(dat$file)
   }
 
@@ -286,7 +294,7 @@ get_release_data <- function(tr = target_repo(github_get = TRUE)) {
     path_first_existing(proj_path(c("CRAN-SUBMISSION", "CRAN-RELEASE")))
 
   if (is.null(cran_submission)) {
-    ui_done("Using current HEAD commit for the release")
+    ui_bullets(c("v" = "Using current HEAD commit for the release."))
     challenge_non_default_branch()
     check_branch_pushed()
     return(list(
@@ -345,14 +353,17 @@ get_release_data <- function(tr = target_repo(github_get = TRUE)) {
 
   out$Package <- project_name()
   out$file <- cran_submission
-  ui_done("
-    {ui_path(out$file)} file found, from a submission on {as.Date(out$Date)}")
+  ui_bullets(c(
+    "{.path {pth(out$file)}} file found, from a submission on {as.Date(out$Date)}."
+  ))
 
   out
 }
 
-check_github_has_SHA <- function(SHA = gert::git_info(repo = git_repo())$commit,
-                                 tr = target_repo(github_get = TRUE)) {
+check_github_has_SHA <- function(
+  SHA = gert::git_info(repo = git_repo())$commit,
+  tr = target_repo(github_get = TRUE)
+) {
   safe_gh <- purrr::safely(gh_tr(tr))
   SHA_GET <- safe_gh(
     "/repos/{owner}/{repo}/git/commits/{commit_sha}",
@@ -362,16 +373,19 @@ check_github_has_SHA <- function(SHA = gert::git_info(repo = git_repo())$commit,
     return()
   }
   if (inherits(SHA_GET$error, "http_error_404")) {
-    ui_stop("
-      Can't find SHA {ui_value(substr(SHA, 1, 7))} in {ui_value(tr$repo_spec)}.
-      Do you need to push?")
+    ui_abort(c(
+      "Can't find SHA {.val {substr(SHA, 1, 7)}} in {.val {tr$repo_spec}}.",
+      "Do you need to push?"
+    ))
   }
-  ui_stop("Internal error: Unexpected error when checking for SHA on GitHub")
+  ui_abort("Internal error: Unexpected error when checking for SHA on GitHub.")
 }
 
-get_release_news <- function(SHA = gert::git_info(repo = git_repo())$commit,
-                             tr = target_repo(github_get = TRUE),
-                             on_cran = !is.null(cran_version())) {
+get_release_news <- function(
+  SHA = gert::git_info(repo = git_repo())$commit,
+  tr = target_repo(github_get = TRUE),
+  on_cran = !is.null(cran_version())
+) {
   HEAD <- gert::git_info(repo = git_repo())$commit
 
   if (HEAD == SHA) {
@@ -390,10 +404,11 @@ get_release_news <- function(SHA = gert::git_info(repo = git_repo())$commit,
   }
 
   if (is.null(news)) {
-    ui_oops("
-      Can't find {ui_path('NEWS.md')} in the released package source.
-      usethis consults this file for release notes.
-      Call {ui_code('usethis::use_news_md()')} to set this up for the future.")
+    ui_bullets(c(
+      "x" = "Can't find {.path {pth('NEWS.md')}} in the released package source.",
+      "i" = "{.pkg usethis} consults this file for release notes.",
+      "i" = "Call {.run usethis::use_news_md()} to set this up for the future."
+    ))
     if (on_cran) "-- no release notes --" else "Initial release"
   } else {
     news_latest(news)
@@ -401,7 +416,6 @@ get_release_news <- function(SHA = gert::git_info(repo = git_repo())$commit,
 }
 
 cran_version <- function(package = project_name(), available = NULL) {
-
   if (!curl::has_internet()) {
     return(NULL)
   }
@@ -433,7 +447,7 @@ news_latest <- function(lines) {
   headings <- which(grepl("^#\\s+", lines))
 
   if (length(headings) == 0) {
-    ui_stop("No top-level headings found in {ui_value('NEWS.md')}")
+    ui_abort("No top-level headings found in {.path {pth('NEWS.md')}}.")
   } else if (length(headings) == 1) {
     news <- lines[seq2(headings + 1, length(lines))]
   } else {
@@ -472,7 +486,8 @@ is_posit_person_canonical <- function() {
     "fnd" %in% roles &&
     "cph" %in% roles &&
     attr(roles, "appears_in", exact = TRUE) == "given" &&
-    attr(roles, "appears_as", exact = TRUE) == "Posit Software, PBC"
+    attr(roles, "appears_as", exact = TRUE) == "Posit Software, PBC" &&
+    attr(roles, "ror", exact = TRUE) %in% "03wc8by49"
 }
 
 get_posit_roles <- function() {
@@ -503,6 +518,10 @@ get_posit_roles <- function() {
     attr(out, "appears_as") <- person$family
     attr(out, "appears_in") <- "family"
   }
+
+  comment <- person$comment %||% character()
+  attr(out, "ror") <- comment["ROR"]
+
   out
 }
 
@@ -514,7 +533,7 @@ is_in_posit_org <- function() {
   urls <- desc$get_urls()
   dat <- parse_github_remotes(urls)
   dat <- dat[dat$host == "github.com", ]
-  purrr::some(dat$repo_owner, ~ .x %in% posit_orgs())
+  purrr::some(dat$repo_owner, \(x) x %in% posit_orgs())
 }
 
 posit_orgs <- function() {
@@ -522,7 +541,8 @@ posit_orgs <- function() {
     "tidyverse",
     "r-lib",
     "tidymodels",
-    "rstudio"
+    "rstudio",
+    "posit-dev"
   )
 }
 
@@ -544,10 +564,11 @@ author_has_rstudio_email <- function() {
 pkg_minimum_r_version <- function() {
   deps <- proj_desc()$get_deps()
   r_dep <- deps[deps$package == "R" & deps$type == "Depends", "version"]
-  if (length(r_dep) == 0) {
-    return(numeric_version("0"))
+  if (length(r_dep) > 0) {
+    numeric_version(gsub("[^0-9.]", "", r_dep))
+  } else {
+    NA_character_
   }
-  numeric_version(gsub("[^0-9.]", "", r_dep))
 }
 
 # Borrowed from pak, but modified also retain user's non-cran repos:
