@@ -6,17 +6,20 @@ can_overwrite <- function(path) {
   if (getOption("usethis.overwrite", FALSE)) {
     # don't activate a project
     # don't assume `path` is in the active project
-    if (is_in_proj(path) && uses_git()) {      # path is in active project
+    if (is_in_proj(path) && uses_git()) {
+      # path is in active project
       return(TRUE)
     }
-    if (possibly_in_proj(path) &&              # path is some other project
-        with_project(proj_find(path), uses_git(), quiet = TRUE)) {
+    if (
+      possibly_in_proj(path) && # path is some other project
+        with_project(proj_find(path), uses_git(), quiet = TRUE)
+    ) {
       return(TRUE)
     }
   }
 
   if (is_interactive()) {
-    ui_yeah("Overwrite pre-existing file {ui_path(path)}?")
+    ui_yep(c("!" = "Overwrite pre-existing file {.path {pth(path)}}?"))
   } else {
     FALSE
   }
@@ -24,12 +27,11 @@ can_overwrite <- function(path) {
 
 check_is_named_list <- function(x, nm = deparse(substitute(x))) {
   if (!is_list(x)) {
-    bad_class <- paste(class(x), collapse = "/")
-    ui_stop("{ui_code(nm)} must be a list, not {ui_value(bad_class)}.")
+    ui_abort("{.code {nm}} must be a list, not {.obj_type_friendly {x}}.")
   }
   if (!is_dictionaryish(x)) {
-    ui_stop(
-      "Names of {ui_code(nm)} must be non-missing, non-empty, and non-duplicated."
+    ui_abort(
+      "Names of {.code {nm}} must be non-missing, non-empty, and non-duplicated."
     )
   }
   x
@@ -97,6 +99,10 @@ is_windows <- function() {
   .Platform$OS.type == "windows"
 }
 
+is_linux <- function() {
+  identical(tolower(Sys.info()[["sysname"]]), "linux")
+}
+
 # For stability of `stringsAsFactors` across versions
 data.frame <- function(..., stringsAsFactors = FALSE) {
   base::data.frame(..., stringsAsFactors = stringsAsFactors)
@@ -104,8 +110,6 @@ data.frame <- function(..., stringsAsFactors = FALSE) {
 
 # wrapper around check_name() from import-standalone-types-check.R
 # for the common case when NULL is allowed (often default)
-maybe_name <- function(x, ..., arg = caller_arg(x),
-                       call = caller_env()) {
-  check_name(x, ..., allow_null = TRUE,
-             arg = arg, call = call)
+maybe_name <- function(x, ..., arg = caller_arg(x), call = caller_env()) {
+  check_name(x, ..., allow_null = TRUE, arg = arg, call = call)
 }
