@@ -6,29 +6,30 @@ test_that("use_data_table() requires a package", {
 test_that("use_data_table() Imports data.table", {
   create_local_package()
   use_package_doc()
-  with_mock(
-    check_installed = function(pkg) TRUE,
-    roxygen_update_ns = function(...) NULL,
-    check_functions_exist = function(...) TRUE,
-    use_data_table()
-  )
+  local_check_installed()
+  local_roxygen_update_ns()
+  local_check_fun_exists()
 
-  expect_match(desc::desc_get("Imports"), "data.table")
+  use_data_table()
+
+  expect_match(proj_desc()$get("Imports"), "data.table")
   expect_snapshot(roxygen_ns_show())
 })
 
 test_that("use_data_table() blocks use of Depends", {
+  local_interactive(FALSE)
+
   create_local_package()
   use_package_doc()
-  desc::desc_set_dep("data.table", "Depends")
-  with_mock(
-    check_installed = function(pkg) TRUE,
-    roxygen_update_ns = function(...) NULL,
-    check_functions_exist = function(...) TRUE,
-    expect_warning(
-      use_data_table(),
-      "data.table should be in Imports or Suggests, not Depends"
-    )
+  desc::desc_set("Depends", "data.table")
+  local_check_installed()
+  local_roxygen_update_ns()
+  local_check_fun_exists()
+
+  withr::local_options(list(usethis.quiet = FALSE))
+  expect_snapshot(
+    use_data_table(),
+    transform = scrub_testpkg
   )
 
   expect_match(desc::desc_get("Imports"), "data.table")
