@@ -102,10 +102,6 @@ test_that("use_github_action() accepts a name", {
   expect_proj_dir(".github/workflows")
   expect_proj_file(".github/workflows/R-CMD-check.yaml")
 
-  yml <- yaml::yaml.load_file(proj_path(".github/workflows/R-CMD-check.yaml"))
-  expect_identical(yml$name, "R-CMD-check")
-  expect_named(yml$jobs, "R-CMD-check")
-
   readme_lines <- read_utf8(proj_path("README.md"))
   expect_match(readme_lines, "R-CMD-check", all = FALSE)
 
@@ -121,7 +117,10 @@ test_that("use_tidy_github_actions() configures the full check and pr commands",
   create_local_package()
   use_git()
   gert::git_add(".gitignore", repo = git_repo())
-  gert::git_commit("a commit, so we are not on an unborn branch", repo = git_repo())
+  gert::git_commit(
+    "a commit, so we are not on an unborn branch",
+    repo = git_repo()
+  )
   use_git_remote(name = "origin", url = "https://github.com/OWNER/REPO")
   use_readme_md()
   use_tidy_github_actions()
@@ -129,16 +128,13 @@ test_that("use_tidy_github_actions() configures the full check and pr commands",
   expect_proj_file(".github/workflows/R-CMD-check.yaml")
 
   yml <- yaml::yaml.load_file(proj_path(".github/workflows/R-CMD-check.yaml"))
-  expect_identical(yml$name, "R-CMD-check")
-  expect_named(yml$jobs, "R-CMD-check")
-
   size_build_matrix <-
     length(yml[["jobs"]][["R-CMD-check"]][["strategy"]][["matrix"]][["config"]])
   expect_gte(size_build_matrix, 6) # release, r-devel, 4 previous versions
 
   expect_proj_file(".github/workflows/pkgdown.yaml")
   expect_proj_file(".github/workflows/test-coverage.yaml")
-  expect_proj_file(".github/workflows/pr-commands.yaml")
+  expect_proj_file(".github/workflows/format-suggest.yaml")
 
   readme_lines <- read_utf8(proj_path("README.md"))
   expect_match(readme_lines, "R-CMD-check", all = FALSE)
