@@ -6,7 +6,7 @@ test_that("use_pipe() requires a package", {
 test_that("use_pipe(export = TRUE) adds promised file, Imports magrittr", {
   create_local_package()
   use_pipe(export = TRUE)
-  expect_match(desc::desc_get("Imports", proj_get()), "magrittr")
+  expect_equal(desc::desc_get_field("Imports"), "magrittr")
   expect_proj_file("R", "utils-pipe.R")
 })
 
@@ -14,8 +14,7 @@ test_that("use_pipe(export = FALSE) adds roxygen to package doc", {
   create_local_package()
   use_package_doc()
   use_pipe(export = FALSE)
-  expect_match(desc::desc_get("Imports", proj_get()), "magrittr")
-  package_doc <- read_utf8(proj_path(package_doc_path()))
-  expect_match(package_doc, "#' @importFrom magrittr %>%", all = FALSE)
-})
+  expect_equal(desc::desc_get_field("Imports"), "magrittr")
 
+  expect_snapshot(roxygen_ns_show())
+})
