@@ -16,7 +16,7 @@ test_that("use_tidy_dependencies() isn't overly informative", {
   skip_if_offline("github.com")
 
   create_local_package()
-  use_package_doc()
+  use_package_doc(open = FALSE)
   withr::local_options(usethis.quiet = FALSE, cli.width = Inf)
 
   expect_snapshot(
@@ -55,30 +55,3 @@ test_that("use_tidy_github() adds and Rbuildignores files", {
   expect_proj_file(".github/CODE_OF_CONDUCT.md")
   expect_true(is_build_ignored("^\\.github$"))
 })
-
-test_that("styling the package works", {
-  skip_if_no_git_user()
-  skip_if_not_installed("styler")
-
-  pkg <- create_local_package()
-  use_r("bad_style")
-  path_to_bad_style <- proj_path("R/bad_style.R")
-  write_utf8(path_to_bad_style, "a++2\n")
-  capture_output(use_tidy_style())
-  expect_identical(read_utf8(path_to_bad_style), "a + +2")
-  file_delete(path_to_bad_style)
-})
-
-
-test_that("styling of non-packages works", {
-  skip_if_no_git_user()
-  skip_if_not_installed("styler")
-
-  proj <- create_local_project()
-  path_to_bad_style <- proj_path("R/bad_style.R")
-  use_r("bad_style")
-  write_utf8(path_to_bad_style, "a++22\n")
-  capture_output(use_tidy_style())
-  expect_identical(read_utf8(path_to_bad_style), "a + +22")
-  file_delete(path_to_bad_style)
-})
