@@ -1,16 +1,16 @@
 test_that("use_import_from() imports the related package & adds line to package doc", {
   create_local_package()
   use_package_doc()
-  use_import_from("tibble", "tibble")
+  use_import_from("lifecycle", "deprecated")
 
-  expect_equal(proj_desc()$get_field("Imports"), "tibble")
-  expect_equal(roxygen_ns_show(), "#' @importFrom tibble tibble")
+  expect_equal(proj_desc()$get_field("Imports"), "lifecycle")
+  expect_equal(roxygen_ns_show(), "#' @importFrom lifecycle deprecated")
 })
 
 test_that("use_import_from() adds one line for each function", {
   create_local_package()
   use_package_doc()
-  use_import_from("tibble", c("tibble", "enframe", "deframe"))
+  use_import_from("lifecycle", c("deprecate_warn", "deprecate_stop"))
 
   expect_snapshot(roxygen_ns_show())
 })
@@ -21,8 +21,8 @@ test_that("use_import_from() generates helpful errors", {
 
   expect_snapshot(error = TRUE, {
     use_import_from(1)
-    use_import_from(c("tibble", "rlang"))
+    use_import_from(c("desc", "rlang"))
 
-    use_import_from("tibble", "pool_noodle")
+    use_import_from("desc", "pool_noodle")
   })
 })
